CoreValues class

Constructors

CoreValues()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

aggregate ↔ List<Map>
total risk score list (current, pairing) To calculate aggregate, MSE score with pairing (devices, employees) Makes Map {Risk Score: Number of Metric}
getter/setter pair
aggregateThreatsScore ↔ String
total risk score each threat (current, pairing) To sum all risk score each threat from (current, pairing)
getter/setter pair
based ↔ Map
getter/setter pair
dependent ↔ Map
threat metrics about company type
getter/setter pair
deviceImplementedRecommendation ↔ Map<String, List<double>>
getter/setter pair
deviceNegative ↔ Map<String, List>
getter/setter pair
devicePositive ↔ Map<String, List>
getter/setter pair
deviceRecommendation ↔ Map<String, List<Map>>
getter/setter pair
deviceThreatScore ↔ Map
getter/setter pair
enabler ↔ Map
getter/setter pair
enterpriseNode ↔ Map
store ':Enterprise' Node information
getter/setter pair
flagMainUser ↔ bool
getter/setter pair
gagg ↔ double
Values from indicator algorithm
getter/setter pair
geigerNameThreatUUID ↔ Map
geiger threat (threat type) (12) {unique} : threat UUID (1...*)
getter/setter pair
geigerThreatNameThreatUUID ↔ Map
geiger threat name (type of threat) (12) {unique} : geiger threat UUID (12) {unique}
getter/setter pair
geigerThreatUUID ↔ List
Global:profile Factor for risk score calculation geiger threat UUID (12) {unique}
getter/setter pair
geigerThreatUUIDThreatName ↔ Map
geiger threat UUID (12) {unique} : geiger threat name (type of threat) (12) {unique}
getter/setter pair
impactValues ↔ Map<String, double>
baseline to convert 'string' of metric about threat, recommendation
getter/setter pair
nagg ↔ String
getter/setter pair
scoreDescription ↔ String
getter/setter pair
threatNameThreatUUID ↔ Map
threat Name (1...) : threat UUID (1...)
getter/setter pair
threatUUIDGeigerName ↔ Map
threat UUID (1...*) : geiger threat name (type of threat) (12) {unique}
getter/setter pair
threatUUIDThreatName ↔ Map
threat UUID (1...) : threat Name (1...)
getter/setter pair
userImplementedRecommendation ↔ Map<String, List<double>>
metric, countermeasures, Users whether follow recommendation or not if user completed recommendation on UI, it delivery to indicator by Storage listener
getter/setter pair
userNegative ↔ Map<String, List>
getter/setter pair
userPositive ↔ Map<String, List>
metrics (positive, negative) key => geiger threat UUID value => geiger value from external plugin
getter/setter pair
userRecommendation ↔ Map<String, List<Map>>
global recommendation metrics from Cloud it is static, defined by cyber security institute
getter/setter pair
userThreatScore ↔ Map
risk score list each threat To calculate total geiger risk score
getter/setter pair
uuidDeviceImplementedRecommendations ↔ List
implemented recommendation list To manage, synchronize latest implemented recommendation list between UI and indicator
getter/setter pair
uuidThreats ↔ List
GEIGER Threats UUID, Name is prefixed on Cloud (Wiki) (About 12, 29,JUL,2022) The name of geiger threats categorize threat domain For example : About Phishing would be exist several 1...* Indicator must to convert threat from external plugin to GEIGER threats threat UUID List
getter/setter pair
uuidUserImplementedRecommendations ↔ List
getter/setter pair